<?php

/**
 * @package     Joomla.Plugin
 * @subpackage  Content.social2s
 *
 * @copyright   Copyright (C) 2005 - 2022 jtotal.org All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

namespace Jtotal\Plugin\Content\Social2s\Helper;

use Joomla\Application\Web\WebClient;
use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Uri\Uri;
use PlgContentSocial2s;

defined('_JEXEC') or die;

class S2sSocial
{

    public static $s2s_obj;

    //check loaded scripts
    public static $s2s_loaded_scripts;

    public function __construct()
    {
        self::$s2s_obj = PlgContentSocial2s::$s2s_obj;
    }

    /*TWITTER*/
    //deprecated
    public function getTwitter(
        $afterplus
    ) {
        return self::getTwitterOwn($afterplus);
    }

    public function getTwitterOwn($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $images_path = self::$s2s_obj->images_path;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        $twitter_user = $params->get('twitter_user', '');
        $twitter_via = $params->get('twitter_via', 0);
        $twitter_counter = $params->get('twitter_count', 0);
        $twitter_follow = $params->get('twitter_follow', 0);
        $twitter_follow_counter = $params->get('twitter_follow_count', 0);

        if ($twitter_user == '') {
            $twitter_follow = 0;
        }

        $s2s_twitter_utf8 = $params->get('s2s_twitter_link_utf8', '0');
        $s2s_twitter_text_utf8 = $params->get('s2s_twitter_text_utf8', '0');

        $full_link_encoded = htmlspecialchars($full_link);
        $full_link_encoded = urlencode($full_link_encoded);
        $full_link_encoded = str_replace('&amp;', '%26', $full_link);

        if ($s2s_twitter_utf8 == '0') {
            $full_link_encoded = str_replace('&amp;', '%26', $full_link);
        } elseif ($s2s_twitter_utf8 == '1') {
            $full_link_encoded = urlencode($full_link_encoded);
        } elseif ($s2s_twitter_utf8 == '2') {
            $full_link_encoded = str_replace('&amp;', '%26', $full_link);
        } elseif ($s2s_twitter_utf8 == '3') {
            $full_link_encoded = htmlspecialchars($full_link);
        }

        if ($s2s_twitter_text_utf8 == '0') {
            $text_encoded = rawurlencode($title);
        } elseif ($s2s_twitter_text_utf8 == '1') {
            $text_encoded = $title;
        } elseif ($s2s_twitter_text_utf8 == '2') {
            $text_encoded = rawurlencode($title);
        } elseif ($s2s_twitter_text_utf8 == '3') {
            $text_encoded = htmlspecialchars($title);
        }

        $via = $twitter_via ? '&via=' . $twitter_user : '';
        $lang_tweet = $this->getTwitterLanguage($idioma_twitter);

        $html = '<div class="s2s_twitter s2s_twitter_own s2s_btn ' . $button_size . ' ' . $afterplus . '">';
        
        $html .= '<a 
                aria-label="open twitter button" 
                aria-controls="s2s_twitter_iframe"
                aria-expanded="false"
                 
                role="button"
                tabindex="'.$tabindex.'"
                onKeyPress="javascript:s2sKeyEnter(this,event);"
                onclick="javascript:s2sClick(this,event);"
                data-url="https://twitter.com/intent/tweet?text=' . $text_encoded . '&url=' . $full_link_encoded . $via . '"
                class="s2s_icon">' . $buttons['twitter'] . ' </a>';

        //DIV //v5.0.0 //deprecated
        $div = '<div class="globo s2s_globo_closed" id="s2s_twitter_iframe">
            <div class="s2s_flecha"></div>';
        
        $iconfont = (self::$s2s_obj->icon_font == 'image') ? '<img src="' . $images_path . 'svg/icon/x-twitter.svg" alt="twitter button" width="16px" height="16px"/>' : '<i class="fab fa-twitter"></i>';

        $div .= '<div class="s2s_div_btn_twitter">';
            $div .= '<a class="s2s_a_btn s2s_btn_twitter" target="_blank" rel="noopener noreferrer" href="https://twitter.com/intent/tweet?text=' . $text_encoded . '&url=' . $full_link_encoded . $via . '">
                    ' . $iconfont . ' ' . $lang_tweet . '</a>';
        $div .= '</div>';
        if ($twitter_follow) {
            $div .= '<a href="https://twitter.com/' . $twitter_user . '" class="s2s_a_btn s2s_a_btn_follow">' . $iconfont . ' ' . Text::_('SOCIAL2S_TWITTER_FOLLOW_TEXT') . '</a>';
        }
        $div .= '</div>';

        $html .= '</div>';

        return $html;
    }

    public function getTwitterLanguage($lang, $follow = false)
    {

        $tweet_lang = array(
            'en' => ' <span>Tweet</span>',
            'ar' => '<span>غرِّد</span> ',
            'bn' => ' <span>টুইট</span>',
            'cs' => ' <span>Tweet</span>',
            'da' => ' <span>Tweet</span>',
            'ca' => ' <span>Tuit</span>',
            'de' => ' <span>Twittern</span>',
            'el' => ' <span>Tweet</span>',
            'es' => ' <span>Twittear</span>',
            'fa' => '<span>توییت</span> ',
            'fi' => ' <span>Twiittaa</span>',
            'fil' => ' <span>I-tweet</span>',
            'fr' => ' <span>Tweeter</span>',
            'he' => '<span>ציוץ</span> ',
            'hi' => ' <span>ट्वीट</span>',
            'hu' => ' <span>Tweet</span>',
            'id' => ' <span>Tweet</span>',
            'it' => ' <span>Tweet</span>',
            'ja' => ' <span>ツイート</span>',
            'ko' => ' <span>트윗</span>',
            'msa' => ' <span>Tweet</span>',
            'nl' => ' <span>Tweeten</span>',
            'no' => ' <span>Tweet</span>',
            'pl' => ' <span>Tweetnij</span>',
            'pt' => ' <span>Tweetar</span>',
            'ro' => ' <span>Tweet</span>',
            'ru' => ' <span>Твитнуть</span>',
            'sv' => ' <span>Tweeta</span>',
            'th' => ' <span>ทวีต</span>',
            'tr' => ' <span>Tweetle</span>',
            'uk' => ' <span>Твіт</span>',
            'ur' => '<span>ٹویٹ کریں</span> ',
            'vi' => ' <span>Tweet</span>',
            'zh-cn' => ' <span>发推</span>',
            'zh-tw' => ' <span>推文</span>',
        );

        $tweet = isset($tweet_lang[$lang]) ? $tweet = $tweet_lang[$lang] : $tweet = $tweet_lang['en'];

        return $tweet;
    }

    public function getTwitterFollow($lang, $follow = false)
    {

        $tweet_lang = array(
            'en' => ' <span>Tweet</span>',
            'ar' => '<span>على تويتر</span>',
            'bn' => ' <span>টুইট</span>',
            'cs' => ' <span>Tweet</span>',
            'da' => ' <span>Tweet</span>',
            'da' => ' <span>Tweet</span>',
            'de' => ' <span>Twittern</span>',
            'el' => ' <span>Tweet</span>',
            'es' => ' <span>Twittear</span>',
            'fa' => '<span>توییت</span> ',
            'fi' => ' <span>Twiittaa</span>',
            'fil' => ' <span>I-tweet</span>',
            'fr' => ' <span>Tweeter</span>',
            'he' => '<span>ציוץ</span> ',
            'hi' => ' <span>ट्वीट</span>',
            'hu' => ' <span>Tweet</span>',
            'id' => ' <span>Tweet</span>',
            'it' => ' <span>Tweet</span>',
            'ja' => ' <span>ツイート</span>',
            'ko' => ' <span>트윗</span>',
            'msa' => ' <span>Tweet</span>',
            'nl' => ' <span>Tweeten</span>',
            'no' => ' <span>Tweet</span>',
            'pl' => ' <span>Tweetnij</span>',
            'pt' => ' <span>Tweetar</span>',
            'ro' => ' <span>Tweet</span>',
            'ru' => ' <span>Твитнуть</span>',
            'sv' => ' <span>Tweeta</span>',
            'th' => ' <span>ทวีต</span>',
            'tr' => ' <span>Tweetle</span>',
            'uk' => ' <span>Твіт</span>',
            'ur' => '<span>ٹویٹ کریں</span> ',
            'vi' => ' <span>Tweet</span>',
            'zh-cn' => ' <span>发推</span>',
            'zh-tw' => ' <span>推文</span>',
        );

        $tweet = isset($tweet_lang[$lang]) ? $tweet = $tweet_lang[$lang] : $tweet = $tweet_lang['en'];

        return $tweet;
    }

    /*FACEBOOK*/
    public function getFacebook($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;
        $images_path = self::$s2s_obj->images_path;

        $s2s_icon_image = self::$s2s_obj->params;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        $facebook_layout = $params->get('facebook_layout', 'button');
        if ($facebook_layout == 'standard') {
            $facebook_layout = 'button';
        }

        //DEPRECATED
        /*
        $facebook_share = $params->get('facebook_share', 0);
        if($facebook_share){
        $fb_share = 'data-share="true"';
        }else{
        $fb_share = 'data-share="false"';
        }
         */

        $fb_share = '';

        if ($jmobile) {
            $fb_mobile = 'data-mobile-iframe=true';
        } else {
            $fb_mobile = 'data-mobile-iframe=false';
            $fb_mobile = 'data-mobile-iframe=true';
        }

        //COUNT

        $facebook_share_count = $params->get('facebook_share_count', 0);

        //Disabled 4.0.141
        $facebook_share_count = 0;

        if ($facebook_share_count) {
            $facebook_s_count_html = '<span class="s2s_badge s2s_fb_count_share">0</span>';
        } else {
            $facebook_s_count_html = '';
        }

        $facebook_like_count = $params->get('facebook_like_count', 0);
        //Disabled 4.0.141
        $facebook_like_count = 0;

        if ($facebook_like_count) {
            $facebook_l_count_html = '<span class="s2s_badge s2s_fb_count_like">0</span>';
        } else {
            $facebook_l_count_html = '';
        }

        //DEPRECATED BY FACEBOOK
        //$facebook_save = $params->get('facebook_save', 0);

        $facebook_size = $params->get('facebook_size', 'small');

        $html = '<div class="s2s_facebook s2s_btn ' . $button_size . ' ' . $afterplus . '" >';
             
        $html .= '<a
                aria-label="open facebook button" 
                aria-expanded="false"
                 
                role="button"
                tabindex="'.$tabindex.'"
                onKeyPress="javascript:s2sKeyEnter(this,event);"
                onclick="javascript:s2sClick(this,event);"
                data-url="https://www.facebook.com/sharer/sharer.php?kid_directed_site=0&sdk=joey&u=' . $full_link . '&display=popup&ref=plugin&src=share_button"
            class="s2s_icon">' . $buttons['facebook'] . $facebook_s_count_html . ' ' . $facebook_l_count_html . '</a>';


            $div = '<div class="globo s2s_globo_closed" id="s2s_facebook_iframe">
                        <div class="s2s_flecha"></div>';

            $iconfont = (self::$s2s_obj->icon_font == 'image') ? '<img src="' . $images_path . 'svg/icon/facebook.svg" alt="twitter button" width="16px" height="16px"/>' : '<i class="fab fa-twitter"></i>';

            $fb_link_noscript = '<a
                target="_blank"
                href="https://www.facebook.com/sharer/sharer.php?kid_directed_site=0&sdk=joey&u=' . $full_link . '&display=popup&ref=plugin&src=share_button"
                class="fb-xfbml-parse-ignore s2s_a_btn">
                ' . $iconfont . ' ' . Text::_('SOCIAL2S_SHARE_TEXT') . '</a>';

                $div .= '<div class="fb-share-button_fallback">' . $fb_link_noscript . '</div>';
                $div .= '</div>';


        $html .= '</div>';

        return $html;
    }

    /*PINTEREST*/
    public function getPinterest($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;
        $images_path = self::$s2s_obj->images_path;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        /*
        //shape
        $pinterest_shape = $params->get('pinterest_shape', 1);
        if($pinterest_shape){
        $pin_shape = 'data-pin-shape="round"';
        }else{
        $pin_shape = '';
        }

        //size
        $pinterest_size = $params->get('pinterest_size', 1);
        if($pinterest_size){
        $pin_size = 'data-pin-tall="true"';
        }else{
        $pin_size = '';
        }

        //COUNT
        $pinterest_count = $params->get('pinterest_count', 0);
        //Disabled 4.0.141
        $pinterest_count = 0;

        if($pinterest_count){
        $pinterest_s_count_html = '<span class="s2s_badge s2s_pinterest_badge_count">0</span>';
        }else{
        $pinterest_s_count_html = '';
        }

        //COUNT in button
        $pinterest_b_count = $params->get('pinterest_b_count', 0);

        if($pinterest_b_count == 0){
        $pinterest_b_count_code = '';
        }elseif($pinterest_b_count == 1){
        $pinterest_b_count_code = 'data-pin-count="above"';
        }else{
        $pinterest_b_count_code = 'data-pin-count="beside"';
        }

        //shape
        $pinterest_color = $params->get('pinterest_color', 'red');
        $pin_color = 'data-pin-color="'.$pinterest_color.'"';

         */

        $document = Factory::getDocument();
        
        $html = '';





        $html .= '<div class="s2s_pinterest s2s_btn ' . $button_size . ' ' . $afterplus . '">';

        $html .= '<a class="s2s_icon"
            aria-label="open pinterest button" 
            aria-expanded="false"
             
            role="button"
            tabindex="'.$tabindex.'"
            onKeyPress="javascript:s2sKeyEnter(this,event);"
            onclick="javascript:s2sClick(this,event);"
            data-url="//www.pinterest.com/pin/create/button/?url=' . rawurlencode(URI::getInstance()->toString()) . '&amp;description=' . rawurlencode($title) . '"
            >' . $buttons['pinterest'] . '</a>';

            $div = '<div class="globo s2s_globo_closed" id="s2s_pinterest_iframe">
                        <div class="s2s_flecha"></div>
                        ';

            //v5.0.0
            $iconfont = (self::$s2s_obj->icon_font == 1) ? '<i class="s2sfo fo-pinterest"></i>' : '<i class="fab fa-pinterest"></i>';

            $div .= '<a class="s2s_a_btn" aria-label="pinterest" href="//www.pinterest.com/pin/create/button/?url=' . rawurlencode(URI::getInstance()->toString()) . '&amp;description=' . rawurlencode($title) . '">';
            $div .= $iconfont . ' ' . Text::_('SOCIAL2S_PINTEREST_PINIT') . '</a>';
            $div .= '</a>';
            $div .= ' </div>';
        $html .= '</div>';

        return $html;
    }

    /*LINKEDIN*/
    public function getLinkedin($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        //v5.0.0
        $iconfont = (self::$s2s_obj->icon_font == 1) ? '<i class="s2sfo fo-linkedin"></i>' : '<i class="fab fa-linkedin"></i>';
        
        $linkedin_link_noscript = '<a
            target="_blank"
            href="https://www.linkedin.com/shareArticle?url=' . rawurlencode(URI::getInstance()->toString()) . '"
            class="s2s_linkedin_fallback s2s_a_btn">
            ' . $iconfont . ' ' . Text::_('SOCIAL2S_SHARE_TEXT') . '</a>';



        $html = '<div class="s2s_linkedin s2s_btn ' . $button_size . ' ' . $afterplus . '" >';

        $html .= '<a class="s2s_icon"
            aria-label="open linkedin" 
            aria-expanded="false"
             
            role="button"
            tabindex="'.$tabindex.'"
            onKeyPress="javascript:s2sKeyEnter(this,event);"
            onclick="javascript:s2sClick(this,event);"
            data-url="https://www.linkedin.com/shareArticle?url=' . rawurlencode(URI::getInstance()->toString()) . '"
            >' . $buttons['linkedin'] . '</a>';

        $div = '<div class="globo s2s_globo_closed s2s_linkedin_iframe">
                        <div class="s2s_flecha"></div>';
        //$html .= $cookie_button.'<script type="IN/Share" '.$linkedin_c.' data-url="'.$full_link.'"></script>';

        $div .= $linkedin_link_noscript;
        $div .= '</div>';

        $html .= '</div>';

        return $html;
    }

    /*GOOGLE PLUS*/
    //DEAD
    public function getGPlus($afterplus)
    {
        return;
    }

    //DEPRECATED
    public static function gplusCount($url)
    {
        return;
    }

    /*WAPP*/
    public function getWapp($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        //check if is mobile
        if ($params->get('wapp_only_mobile', 0)) {
            $wapp_only_mobile = 'visible-xs';

            if (!$jmobile) {
                return '';
            }
        } else {
            $wapp_only_mobile = '';
        }
        //v5.0.0
        $iconfont = (self::$s2s_obj->icon_font == 1) ? '<i class="s2sfo fo-whatsapp"></i>' : '<i class="fab fa-whatsapp"></i>';
        $html = '<div class="s2s_wapp s2s_btn ' . $button_size . ' ' . $wapp_only_mobile . ' ' . $afterplus . '" >

            <a class="s2s_icon"
                href="whatsapp://send?text=' . urlencode($full_link) . '"
                data-text="' . $title . '"
                data-action="share/whatsapp/share"
                data-href="' . urlencode($full_link) . '"
                tabindex="'.$tabindex.'"
            >' . $buttons['wapp'] . '</a>';


            $div = '<div class="globo s2s_globo_closed s2s_wapp_iframe">
                    <div class="s2s_flecha"></div>


                <a class="s2s_a_btn wapp_link"
                    href="whatsapp://send?text=' . urlencode($full_link) . '"
                    data-text="' . $title . '"
                    data-action="share/whatsapp/share"
                    data-href="' . urlencode($full_link) . '"
                >
                    ' . $iconfont . '
                    <span class="s2s_text_int">' . Text::_('SOCIAL2S_SHARE_TEXT') . '</span>
                </a>

                </div>';
        $html .= '</div>';

        return $html;
    }

    /*TGRAM*/
    public function getTgram($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        //check if is mobile
        if ($params->get('tgram_only_mobile', 0)) {
            $tgram_only_mobile = 'visible-xs';

            $doc = Factory::getDocument();

            // 4.0
            $appWeb = new WebClient;

            if (!$appWeb->mobile) {
                return '';
            }
        } else {
            $tgram_only_mobile = '';
        }

        //v5.0.0
        $iconfont = (self::$s2s_obj->icon_font == 1) ? '<i class="s2sfo fo-telegram"></i>' : '<i class="fab fa-telegram"></i>';

        $html = '<div class="s2s_tgram s2s_btn ' . $button_size . ' ' . $tgram_only_mobile . ' ' . $afterplus . '" >

            <a class="s2s_icon" 
                aria-label="open telegram" 
                aria-expanded="false"
                 
                role="button"
                tabindex="'.$tabindex.'"          
                href="https://telegram.me/share/url?url=' . urlencode($full_link) . '&text=' . $title . '" target="_blank"
            >' . $buttons['tgram'] . '</a>';
            //href="https://telegram.me/share/url?url=' . urlencode($full_link) . '&text=' . $title . '" target="_blank"
            $div = '
                <div class="globo s2s_globo_closed s2s_tgram_iframe">
                    <div class="s2s_flecha"></div>

                <a class="s2s_a_btn tgram_link" rel="noreferrer"
                    href="https://telegram.me/share/url?url=' . urlencode($full_link) . '&text=' . $title . '" target="_blank"
                >' . $iconfont . '<span class="s2s_text_int">' . Text::_('SOCIAL2S_SHARE_TEXT') . '<span></a>

                </div>';


        $html .= '</div>';

        return $html;
    }

    /*FLIPB*/
    public function getFlipb($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        //check if is mobile
        if ($params->get('flipb_only_mobile', 0)) {
            $flipb_only_mobile = 'visible-xs';
            if (!$jmobile) {
                return '';
            }
        } else {
            $flipb_only_mobile = '';
        }

        //v5.0.0
        $iconfont = (self::$s2s_obj->icon_font == 1) ? '<i class="s2sfo fo-flipb"></i>' : '<i class="fab fa-flipboard"></i>';

        $html = '<div class="s2s_flipb s2s_btn ' . $button_size . ' ' . $flipb_only_mobile . ' ' . $afterplus . '" >';

        $html .= '<a class="s2s_icon" 
            aria-label="open flipboard" 
            aria-expanded="false"
             
            role="button"        
            tabindex="'.$tabindex.'"       
            onKeyPress="javascript:s2sKeyEnter(this,event);"
            onclick="javascript:s2sClick(this,event);"
            data-url="https://share.flipboard.com/bookmarklet/popout?v=2&title=Blog&url=' . urlencode($full_link) . '&t=1662478911114&utm_campaign=tools&utm_medium=article-share" 
        >' . $buttons['flipb'] . '</a>';


                $div = '<div class="globo s2s_globo_closed s2s_flipb_iframe">
                    <div class="s2s_flecha"></div>';
                $div .= '<a class="s2s_a_btn flipb_link" rel="noreferrer"
                        href="https://share.flipboard.com/bookmarklet/popout?v=2&title=Blog&url=' . urlencode($full_link) . '&t=1662478911114&utm_campaign=tools&utm_medium=article-share" target="_blank"
                        >' . $iconfont . '<span class="s2s_text_int">' . Text::_('SOCIAL2S_SHARE_FLIP') . '<span></a>';

                $div  .= '</div>';
        $html .= '</div>';


        return $html;
    }

    //SNAP
    //
    public function getSnap($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        $doc = Factory::getDocument();
        //check if is mobile
        if ($params->get('snap_only_mobile', 0)) {
            $snap_only_mobile = 'visible-xs';
            if (!$jmobile) {
                return '';
            }
        } else {
            $snap_only_mobile = '';
        }

        //v5.0.0
        $iconfont = '<i class="fab fa-snapchat"></i>';

        $html = '<div class="s2s_snap s2s_btn ' . $button_size . ' ' . $snap_only_mobile . ' ' . $afterplus . '" >';

        $html .= '<a class="s2s_icon" 
            aria-label="open snapchat" 
            aria-expanded="false"
             
            role="button"   
            tabindex="'.$tabindex.'"            
            onKeyPress="javascript:s2sKeyEnter(this,event);"
            onclick="javascript:s2sClick(this,event);"
            data-url="https://snapchat.com/scan?attachmentUrl=' . rawurlencode(URI::getInstance()->toString()) . '&utm_source=' . self::$s2s_obj->sitename . '"
        >' . $buttons['snap'] . '</a>';

        $div = '<div class="globo s2s_globo_closed s2s_snap_iframe">
                    <div class="s2s_flecha"></div>';
        $div .= '<a class="s2s_a_btn snapchat_link" target="_blank" href="https://snapchat.com/scan?attachmentUrl=' . rawurlencode(URI::getInstance()->toString()) . '&utm_source=' . self::$s2s_obj->sitename . '">';
        $div .= $iconfont . ' ' . Text::_('SOCIAL2S_SHARE_TEXT') . '</a>';
        $div .=  '</div>';

        $html .= '</div>';

        return $html;
    }
    /*REDDIT*/
    public function getReddit($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        //v5.0.0
        $iconfont = (self::$s2s_obj->icon_font == 1) ? '<i class="s2sfo fo-reddit"></i>' : '<i class="fab fa-reddit"></i>';

        $html = '<div class="s2s_reddit s2s_btn ' . $button_size . ' ' . $afterplus . '" lang="' . $idioma_twitter . '">
            <a class="s2s_icon" 
                aria-label="open reddit" 
                aria-expanded="false"
                 
                role="button"   
                tabindex="'.$tabindex.'"    
                onKeyPress="javascript:s2sKeyEnter(this,event);"
                onclick="javascript:s2sClick(this,event);"       
                data-url="//www.reddit.com/submit?url=' . urlencode($full_link) . '"
            >' . $buttons['reddit'] . '</a>';
            $div = '<div class="globo s2s_globo_closed s2s_reddit_iframe">
                <div class="s2s_flecha"></div>';
            $div .= '<a class="s2s_a_btn reddit_link" rel="noreferrer"
                        href="//www.reddit.com/submit?url=' . urlencode($full_link) . '"
                        target="_blank"
                    >' . $iconfont . ' <span class="s2s_text_int">' . Text::_('SOCIAL2S_SHARE_TEXT') . '<span></a>';
            $div .= '</div>';

        $html .= '</div>';

        return $html;
    }

    /*TUMBLR*/
    public function getTumblr($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        $tumblr_follow = $params->get('tumblr_follow', 0);
        $tumblr_user = $params->get('tumblr_user', '');
        $tumblr_counter = $params->get('tumblr_counter', 0);

        if ($tumblr_counter == 2) {
            $tumblr_c = 'data-notes="top"';
        } elseif ($tumblr_counter == 1) {
            $tumblr_c = 'data-notes="right"';
        } else {
            $tumblr_c = '';
        }

        //COUNT
        $tumblr_count = $params->get('tumblr_count', 0);
        //disabled in 4.0.141
        $tumblr_count = 0;

        if ($tumblr_count) {
            $tumblr_s_count_html = '<span class="s2s_badge s2s_tumblr_badge_count">0</span>';
        } else {
            $tumblr_s_count_html = '';
        }

        $tumblr_color = $params->get('tumblr_color', 'blue');

        //v5.0.0
        $iconfont = (self::$s2s_obj->icon_font == 1) ? '<i class="s2sfo fo-tumblr"></i>' : '<i class="fab fa-tumblr"></i>';

        $html = '<div class="s2s_tumblr s2s_btn ' . $button_size . ' ' . $afterplus . '" lang="' . $idioma_twitter . '">
        
        
            <a class="s2s_icon" 
                aria-label="open tumblr" 
                aria-expanded="false"
                
                role="button"
                tabindex="'.$tabindex.'"
                onKeyPress="javascript:s2sKeyEnter(this,event);"
                onclick="javascript:s2sClick(this,event);"
                data-url="//www.tumblr.com/share/link?url=' . urlencode($full_link) . '&name=' . urlencode($title) . '"
            >' . $buttons['tumblr'] . ' ' . $tumblr_s_count_html . '</a>';


            $div = '<div class="globo s2s_globo_closed s2s_tumblr_iframe">
                    <div class="s2s_flecha"></div>';
            $div .= '<a class="s2s_a_btn tumblr_link" rel="noreferrer"
                        href="//www.tumblr.com/share/link?url=' . urlencode($full_link) . '&name=' . urlencode($title) . '"
                        target="_blank">' . $iconfont . ' <span class="s2s_text_int">' . Text::_('SOCIAL2S_SHARE_TEXT') . '<span></a>';
            $div .= '</div>';


        $html .= '</div>';

        return $html;
    }

    /*VK*/
    public function getVk($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        //var_dump($tabindex);

        //v5.0.0
        $iconfont = (self::$s2s_obj->icon_font == 1) ? '<i class="s2sfo fo-vk"></i>' : '<i class="fab fa-vk"></i>';

        $html = '<div class="s2s_vk s2s_btn ' . $button_size . ' ' . $afterplus . '" lang="' . $idioma_twitter . '">
        
        <a class="s2s_icon" 
                aria-label="open vk" 
                aria-expanded="false"
                
                role="button"
                tabindex="'.$tabindex.'"
                onKeyPress="javascript:s2sKeyEnter(this,event);"
                onclick="javascript:s2sClick(this,event);"
                data-url="https://oauth.vk.com/authorize?client_id=-1&redirect_uri=https%3A%2F%2Fvk.com%2Fshare.php%3Furl%3D' . rawurlencode(URI::getInstance()->toString()) . '&display=widget"
            >' . $buttons['vk'] . ' </a>';

            $div = '<div class="globo s2s_globo_closed s2s_vk_iframe" id="s2s_vk_iframe">
                        <div class="s2s_flecha"></div>';

            $div .= '<a class="s2s_a_btn vk_link" rel="noreferrer"
                            href="https://oauth.vk.com/authorize?client_id=-1&redirect_uri=https%3A%2F%2Fvk.com%2Fshare.php%3Furl%3D' . rawurlencode(URI::getInstance()->toString()) . '&display=widget"
                            target="_blank"
                        >' . $iconfont . ' <span class="s2s_text_int">' . Text::_('SOCIAL2S_SHARE_TEXT') . '<span></a>';
            $div .= '</div>';
        $html .= '</div>';


        return $html;
    }

    /*EMAIL*/
    public function getEmail($afterplus)
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $tabindex = ($afterplus == 'afterplus') ? '1' : '0';

        //$body = htmlspecialchars('<a href="'.urlencode($full_link).'" target="_blank"></a>');

        $html = '<div class="s2s_email s2s_btn ' . $button_size . ' ' . $afterplus . '" >

            <a class="s2s_icon" 
                tabindex="'.$tabindex.'" 
                href="mailto:?Subject=' . $title . '&body=' . urlencode($full_link) . '"
            >' . $buttons['email'] . '</a>';


            $div = '<div class="globo s2s_globo_closed s2s_email_iframe">
                    <div class="s2s_flecha"></div>

                <a class="s2s_a_btn email_link"
                    href="mailto:?Subject=' . $title . '&body=' . urlencode($full_link) . '"
                ><i class="s2sfo fo-email" aria-hidden="true"></i><span class="s2s_text_int">' . Text::_('SOCIAL2S_EMAIL_SHARE') . '<span></a>

                </div>';

                $html  .= '</div>';

        return $html;
    }

    /*MAS*/
    public function getMas()
    {

        //COMMON
        $params = self::$s2s_obj->params;
        $styles = self::$s2s_obj->styles;

        $full_link = self::$s2s_obj->full_link;
        $title = self::$s2s_obj->title;
        $button_size = $styles->size;
        $buttons = S2sTmpl::$s2s_buttons;
        $cookie_button = self::$s2s_obj->cookie_button;
        $idioma = self::$s2s_obj->lang;
        $idioma_twitter = self::$s2s_obj->lang_twitter;
        $texts = S2sTmpl::getTexts($styles->text);
        $jmobile = self::$s2s_obj->jmobile;

        $s2s_icon_image = $params->get('s2s_icon_image', 'fa');
        $s2s_icon_image_custom = $params->get('mas_style_custom', 'fas fa-plus-square');
        $mas_button = '';

        $image_pixels = $styles->image_size;


        //s2sFO
        //DEP
        /*
        if ($s2s_icon_image == '1') {
            $mas_style = $params->get('mas_style', 'rplus_q');
            $mas_button = '<a><i class="s2sfo fo-' . $mas_style . '"></i></a>';
        }
        */

        //s2s FA
        if ($s2s_icon_image == 'fa') {
            $mas_style = $params->get('mas_style', 'plus-square');

            if ($mas_style == 'plus-square') {
                $mas_button = '<a aria-label="open social buttons" 
                    aria-expanded="false"
                    role="button"
                    tabindex="0">
                    <i class="fas fa-plus-square"></i><i class="fas fa-minus-square"></i>
                </a>';
            }
            if ($mas_style == 'plus-circle') {
                $mas_button = '<a aria-label="open social buttons" 
                aria-expanded="false"
                role="button"
                tabindex="0">
                    <i class="fas fa-plus-circle"></i>
                    <i class="fas fa-minus-circle"></i>
                </a>';
            }

            if ($mas_style == 'rplus_q') {
                $mas_button = '<a><i class="far fa-plus-square"></i></a>';
            }
            if ($mas_style == 'rplus_s') {
                $mas_button = '<a><i class="fas fa-search-plus"></i></a>';
            }
            //custom
            if ($mas_style == 'plus_custom') {
                $mas_button = '<a><i class="' . $s2s_icon_image_custom . '"></i></a>';
            }
        }


        //images
        if ($s2s_icon_image == 'image') {

            $mas_style = $params->get('mas_style', 'plus-square');

            if ($mas_style == 'plus-square') {
                $mas_button = '<a aria-label="open social buttons" 
                    aria-expanded="false"
                    role="button"
                    tabindex="0">
                    <img src="media/plg_content_social2s/assets/svg/plus-square-solid.svg" alt="twitter button" width="' . $image_pixels . '" height="' . $image_pixels . '"/>
                    <img src="media/plg_content_social2s/assets/svg/minus-square-solid.svg" alt="twitter button" width="' . $image_pixels . '" height="' . $image_pixels . '"/>
                </a>';
            }
            if ($mas_style == 'plus-circle') {
                $mas_button = '<a aria-label="open social buttons" 
                aria-expanded="false"
                role="button"
                tabindex="0">
                    <img src="media/plg_content_social2s/assets/svg/plus-circle-solid.svg" alt="twitter button" width="' . $image_pixels . '" height="' . $image_pixels . '"/>
                    <img src="media/plg_content_social2s/assets/svg/minus-circle-solid.svg" alt="twitter button" width="' . $image_pixels . '" height="' . $image_pixels . '"/>
                </a>';
            }

            if ($mas_style == 'rplus_q') {
                $mas_button = '<a aria-label="open social buttons" 
                aria-expanded="false"
                role="button"
                tabindex="0">
                    <i class="far fa-square-plus"></i>
                    <i class="far fa-square-minus"></i></a>';
            }
            if ($mas_style == 'rplus_s') {
                $mas_button = '<a aria-label="open social buttons" 
                aria-expanded="false"
                role="button"
                tabindex="0">
                    <i class="fas fa-search-plus"></i></a>
                    <i class="fas fa-minus-plus"></i></a>';
            }
            //custom
            if ($mas_style == 'plus_custom') {
                $mas_button = '<a aria-label="open social buttons" 
                aria-expanded="false"
                role="button"
                tabindex="0">
                    ' . $s2s_icon_image_custom . '</a>';
            }
        }


        //check if is mobile
        //if($params->get('mas_only_mob',0)){
        if ($params->get('mas_on', 0) == '2') {
            $wapp_only_mobile = 'visible-xs';

            if (!$jmobile) {
                return '';
            }
        } else {
            $wapp_only_mobile = '';
        }

        $html = '<div class="s2s_mas s2s_btn ' . $button_size . ' ' . $wapp_only_mobile . ' s2s_mas_style_' . $s2s_icon_image . '" >';

        //$html .=    '<a><i class="fa fa-plus-circle"></i></a>';
        $html .= $mas_button;

        $html .= '</div>';

        //$html ='';

        return $html;
    }
}
